@@ -242,6 +242,13 @@ pub mod build {
       self
     }
 
+    /// Alias for `image_url`.
+    pub fn src<S>(self, image_url: S) -> ImageBuilder<'a, Set<method::url>, Alt>
+      where S: Into<Cow<'a, str>>
+    {
+      self.image_url(image_url)
+    }
+
     /// Set `image_url` (**Required**)
     ///
     /// The URL of the image to be displayed.
@@ -278,6 +285,13 @@ pub mod build {
                      state: PhantomData::<_> }
     }
 
+    /// Alias for `alt_text`.
+    pub fn alt<S>(self, alt_text: S) -> ImageBuilder<'a, Url, Set<method::alt>>
+      where S: Into<Cow<'a, str>>
+    {
+      self.alt_text(alt_text)
+    }
+
     /// Set `block_id` (Optional)
     ///
     /// A string acting as a unique identifier for a block.
